import os
try:
  import coverage
  my_coverage = coverage.coverage(source=['xboa.Hit', 'xboa.Bunch', 'xboa.Common', 'xboa.tracking', 'xboa.algorithms'])
  my_coverage.start()
except Exception:
  my_coverage = None

import unittest
import StringIO
import sys
import time
import math
import string
try:
  import numpy
  from numpy import linalg
except ImportError:
  pass
import operator
import bisect

import xboa.test.CommonTest
import xboa.test.HitTest
import xboa.test.BunchTest
import xboa.test.SystemTest

import xboa.Common as Common
import xboa.Hit
import xboa.Bunch


"""
Test script:
One test function for each app function; one test function for each module. Name of each function test is blah_test(...) 
Helper functions are private.
Return value 'fail'; 'warning'; 'pass'
Module test function is called test_module
All tests are called by test_all
So:
  to run all tests call test_all()
"""
__float_tol = Common.float_tolerance

def main():
  sys.stdout = open('test.log', 'w')
  test_new()
  results = test_old()
  print '\n================\n|| XBOA TESTS ||\n================'
  print 'Passed ',results[0],' tests\nFailed ',results[1],' tests\n',results[2],' warnings\n\n\n'
  return

def test_new():
  result = unittest.TextTestResult(sys.stdout, 1, 1)
  loader = unittest.TestLoader().discover('xboa/test/test_tracking/', '*.py')
  loader.run(result)
  loader = unittest.TestLoader().discover('xboa/test/test_algorithms/', '*.py')
  loader.run(result)

def test_old():
  (common_p, common_f, common_w) = xboa.test.CommonTest.test_common()
  (hit_p,    hit_f,    hit_w)    = xboa.test.HitTest.test_hit()
  (bunch_p,  bunch_f,  bunch_w)  = xboa.test.BunchTest.test_bunch()
  (system_p, system_f, system_w) = xboa.test.SystemTest.test_system()
  return (common_p+hit_p+bunch_p+system_p, common_f+hit_f+bunch_f+system_f, common_w+hit_w+bunch_w+system_w)

if __name__ == '__main__':
  main()
  print "Making coverage report"
  if my_coverage != None:
    try:
        my_coverage.stop()
        my_coverage.html_report()
    except Exception:
        pass
